@@ -1,23 +1,25 @@
-/* $Id: netload.h,v 1.3 1998/10/26 12:21:24 martin Exp $ */
+/* $Id$ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_NETLOAD_H__
 #define __GLIBTOP_NETLOAD_H__
@@ -25,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_NETLOAD_IF_FLAGS	0
 #define GLIBTOP_NETLOAD_MTU		1
@@ -92,14 +94,14 @@ struct _glibtop_netload
 #define glibtop_get_netload_r	glibtop_get_netload_s
 #endif
 
-extern void glibtop_get_netload_l __P((glibtop *, glibtop_netload *, const char *));
+void glibtop_get_netload_l (glibtop *server, glibtop_netload *buf, const char *interface);
 
 #if GLIBTOP_SUID_NETLOAD
-extern void glibtop_init_netload_p __P((glibtop *));
-extern void glibtop_get_netload_p __P((glibtop *, glibtop_netload *, const char *));
+void glibtop_init_netload_p (glibtop *server);
+void glibtop_get_netload_p (glibtop *server, glibtop_netload *buf, const char *interface);
 #else
-extern void glibtop_init_netload_s __P((glibtop *));
-extern void glibtop_get_netload_s __P((glibtop *, glibtop_netload *, const char *));
+void glibtop_init_netload_s (glibtop *server);
+void glibtop_get_netload_s (glibtop *server, glibtop_netload *buf, const char *interface);
 #endif
 
 #ifdef GLIBTOP_NAMES
@@ -113,6 +115,6 @@ extern const char *glibtop_descriptions_netload [];
 
 #endif
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
