@@ -1,4 +1,4 @@
-/* $Id: proctime.c,v 1.13.4.3 1999/05/27 18:56:51 martin Exp $ */
+/* $Id$ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -188,7 +188,7 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 	buf->cutime = tv2sec (pstats.p_cru.ru_utime);
 	buf->cstime = tv2sec (pstats.p_cru.ru_stime);
 
-	buf->start_time = tv2sec (pstats.p_start);
+	buf->start_time = (u_int64_t) pstats.p_start.tv_sec;
 
 	buf->flags |= _glibtop_sysdeps_proc_time_user;
 #else
